class Stack:
    def __init__(self): self.stack = []
    def push(self,element):
        if type(element) != list:
            self.stack.append(element)
        else:
            for t in element:
                self.stack.append(t)
    def pop(self): self.stack.pop(-1)
    def top(self): return self.stack[-1]
    def bottom(self): return self.stack[0]
    def isEmpty(self):
        if len(self.stack)>=1:
            return False
        else:
            return True
    def get_stack(self): return self.stack
    def size(self): return len(self.stack)
class Queue:
    def __init__(self): self.queue = []
    def enqueue(self,element):
        if type(element) != list:
            self.queue.append(element)
        else:
            for t in element:
                self.queue.append(t)
    def dequeue(self): self.queue.pop(0)
    def front(self): return self.queue[0]
    def back(self): return self.queue[-1]
    def isEmpty(self):
        if len(self.queue)==0:
            return True
        else:
            return False
    def size(self): return len(self.queue)
    def get_queue(self): return self.queue


from setuptools import setup
with open('README.md') as f:
    long_description = f.read()
setup(
  name = 'py-data-structure',
  packages = ['py_data_structure'],
  version = '0.1.3',
  license='MIT',  
  description = 'A package that allows you to implement C++ data structures in Python.',
  long_description=long_description,
  long_description_content_type='text/markdown',
  author = 'Vihan',
  author_email = 'vihan.raval1@gmail.com',
  url = 'https://github.com/tinyCodersDen/py-data-structure',
  download_url = 'https://github.com/tinyCodersDen/py-data-structure/archive/refs/tags/v_0.1.3.tar.gz',
  keywords = ['Data','structures','data structures','stacks','queues'],
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'License :: OSI Approved :: MIT License'
  ],
)